@@ -1,20 +1,8 @@
-/*****************************************************************************
- * Copyright (c) 2011-2012 Sven Brauch <svenbrauch@googlemail.com>           *
- *                                                                           *
- * This program is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU General Public License as            *
- * published by the Free Software Foundation; either version 2 of            *
- * the License, or (at your option) any later version.                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************
- */
+/*
+    SPDX-FileCopyrightText: 2011-2012 Sven Brauch <svenbrauch@googlemail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "context.h"
 
@@ -310,7 +298,7 @@ PythonCodeCompletionContext::ItemList PythonCodeCompletionContext::inheritanceIt
         // The class completion is a member access
         auto v = visitorForString(m_guessTypeOfExpression, m_duContext.data());
         if ( v ) {
-            TypePtr<StructureType> cls = StructureType::Ptr::dynamicCast(v->lastType());
+            auto cls = v->lastType().dynamicCast<StructureType>();
             if ( cls && cls->declaration(m_duContext->topContext()) ) {
                 if ( DUContext* internal = cls->declaration(m_duContext->topContext())->internalContext() ) {
                     declarations = internal->allDeclarations(m_position, m_duContext->topContext(), false);
@@ -728,7 +716,7 @@ QList< CompletionTreeItemPointer > PythonCodeCompletionContext::getCompletionIte
     }
 
     QList<CompletionTreeItemPointer> result;
-    UnsureType::Ptr unsure = type.cast<UnsureType>();
+    auto unsure = type.staticCast<UnsureType>();
     int count = unsure->typesSize();
     for ( int i = 0; i < count; i++ ) {
         result.append(getCompletionItemsForOneType(unsure->types()[i].abstractType()));
@@ -773,7 +761,7 @@ QList<CompletionTreeItemPointer> PythonCodeCompletionContext::getCompletionItems
         return ItemList();
     }
     // find properties of class declaration
-    TypePtr<StructureType> cls = StructureType::Ptr::dynamicCast(type);
+    auto cls = type.dynamicCast<StructureType>();
     qCDebug(KDEV_PYTHON_CODECOMPLETION) << "Finding completion items for class type";
     if ( ! cls || ! cls->internalContext(m_duContext->topContext()) ) {
         qCWarning(KDEV_PYTHON_CODECOMPLETION) << "No class type available, no completion offered";
