@@ -1,24 +1,8 @@
 /*
- * This file is part of kdev-python, the Python language support plugin for KDevelop
- * Copyright 2013 Sven Brauch <svenbrauch@gmail.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    SPDX-FileCopyrightText: 2013 Sven Brauch <svenbrauch@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "missingincludeassistant.h"
 #include <docfilekcm/docfilewizard.h>
@@ -31,7 +15,7 @@
 
 #include <QDebug>
 #include <QStandardPaths>
-#include "../duchaindebug.h"
+#include <duchaindebug.h>
 
 
 #include <KLocalizedString>
@@ -69,18 +53,25 @@ QString DocumentationGeneratorAction::description() const
 void DocumentationGeneratorAction::execute()
 {
     // yes, it's duplicate from the doc file widget, but it's too painful to share it
-    QDir dir(QStandardPaths::GenericDataLocation + "kdevpythonsupport/documentation_files/");
-    dir.mkpath(QStandardPaths::GenericDataLocation + "kdevpythonsupport/documentation_files/");
     QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/" + "kdevpythonsupport/documentation_files/";
-    DocfileWizard wizard(path);
-    wizard.setModuleName(module);
-    wizard.exec();
-    if ( ! wizard.wasSavedAs().isNull() ) {
-        ICore::self()->documentController()->openDocument(QUrl::fromLocalFile(wizard.wasSavedAs()));
-        // force a recursive update of the context, so that all the imports are reparsed too
-        // (since they potentially have changed through this action)
-        ICore::self()->languageController()->backgroundParser()->addDocument(document, TopDUContext::ForceUpdateRecursive);
-    }
+    QDir dir(path);
+    dir.mkpath(path);
+    auto wizard = new DocfileWizard(path);
+    wizard->setModuleName(module);
+    wizard->setModal(true);
+    wizard->setAttribute(Qt::WA_DeleteOnClose);
+    wizard->show();
+    QObject::connect(wizard, &QDialog::accepted,
+        [wizard, this]() {
+            if ( ! wizard->wasSavedAs().isNull() ) {
+                ICore::self()->documentController()->openDocument(QUrl::fromLocalFile(wizard->wasSavedAs()));
+                // force a recursive update of the context, so that all the imports are reparsed too
+                // (since they potentially have changed through this action)
+                ICore::self()->languageController()->backgroundParser()->addDocument(document, TopDUContext::ForceUpdateRecursive);
+            }
+        }
+    );
+
     emit executed(this);
 }
 
@@ -99,3 +90,4 @@ MissingIncludeAssistant::MissingIncludeAssistant(const QString& module, const In
 
 }
 
+#include "moc_missingincludeassistant.cpp"
